(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory(require('@fortawesome/fontawesome')) :
	typeof define === 'function' && define.amd ? define(['@fortawesome/fontawesome'], factory) :
	(global['vue-fontawesome'] = factory(global.FontAwesome));
}(this, (function (fontawesome) { 'use strict';

fontawesome = fontawesome && fontawesome.hasOwnProperty('default') ? fontawesome['default'] : fontawesome;

function preserveCamelCase(str) {
	var isLastCharLower = false;
	var isLastCharUpper = false;
	var isLastLastCharUpper = false;

	for (var i = 0; i < str.length; i++) {
		var c = str[i];

		if (isLastCharLower && /[a-zA-Z]/.test(c) && c.toUpperCase() === c) {
			str = str.substr(0, i) + '-' + str.substr(i);
			isLastCharLower = false;
			isLastLastCharUpper = isLastCharUpper;
			isLastCharUpper = true;
			i++;
		} else if (isLastCharUpper && isLastLastCharUpper && /[a-zA-Z]/.test(c) && c.toLowerCase() === c) {
			str = str.substr(0, i - 1) + '-' + str.substr(i - 1);
			isLastLastCharUpper = isLastCharUpper;
			isLastCharUpper = false;
			isLastCharLower = true;
		} else {
			isLastCharLower = c.toLowerCase() === c;
			isLastLastCharUpper = isLastCharUpper;
			isLastCharUpper = c.toUpperCase() === c;
		}
	}

	return str;
}

var index = function (str) {
	if (arguments.length > 1) {
		str = Array.from(arguments)
			.map(function (x) { return x.trim(); })
			.filter(function (x) { return x.length; })
			.join('-');
	} else {
		str = str.trim();
	}

	if (str.length === 0) {
		return '';
	}

	if (str.length === 1) {
		return str.toLowerCase();
	}

	if (/^[a-z0-9]+$/.test(str)) {
		return str;
	}

	var hasUpperCase = str !== str.toLowerCase();

	if (hasUpperCase) {
		str = preserveCamelCase(str);
	}

	return str
		.replace(/^[_.\- ]+/, '')
		.toLowerCase()
		.replace(/[_.\- ]+(\w|$)/g, function (m, p1) { return p1.toUpperCase(); });
};

function styleToObject (style) {
  return style.split(';')
    .map(function (s) { s.trim(); })
    .reduce(function (acc, pair) {
      var i = pair.indexOf(':');
      var prop = pair.slice(0, i);
      var value = pair.slice(i + 1).trim();
      return acc[index(prop)] = value
    }, {})
}

function classToObject (cls) {
  return cls.split(/\s+/)
    .reduce(function (acc, c) {
      acc[c] = true;
      return acc
    }, {})
}

function convert (h, element, props) {
  if ( props === void 0 ) props = {};

  var children = (element.children || []).map(convert.bind(null, h));

  var mixins = Object.keys(element.attributes).reduce(function (acc, key) {
    var val = element.attributes[key];

    switch (key) {
      case 'class':
        acc['class'] = classToObject(val);
        break
      case 'style':
        acc['style'] = styleToObject(val);
        break
      default:
        acc.attrs[key] = val;
    }

    return acc
  }, { 'class': {}, style: {}, attrs: {} });

  return h(
    element.tag,
    {
      class: mixins.class,
      style: mixins.style,
      attrs: mixins.attrs,
      props: props
    },
    children
  )
}

var icon$1 = {
  name: 'FontAwesomeIcon',

  props: {
    name: { 
      type: String,
      default: ''
    },
    pack: { 
      type: String,
      default: 'fa' 
    },
    iconDefinition: {
      type: Object,
      default: null
    }
  },

  data: function data () {
    return {
      packNames: {
        brands: 'fab',
        light: 'fal',
        regular: 'far',
        solid: 'fas'
      }
    }
  },

  computed: {
    prefix: function prefix () {
      return this.packNames[this.pack] || this.pack
    },

    iconConfig: function iconConfig () {
      return { prefix: this.prefix, iconName: this.name }
    },

    icon: function icon () {
      return fontawesome.icon(this.iconDefinition || this.iconConfig)
    }
  },

  render: function render (createElement) {
    var ref = this.icon;
    var abstract = ref.abstract;
    var convertCurry = convert.bind(null, createElement);

    return convertCurry(abstract[0])
  }
};

return icon$1;

})));
